pub struct CompositorState { /* private fields */ }Available on crate feature
wayland_frontend only.Expand description
State of a compositor
Implementations
Sourceimpl CompositorState
impl CompositorState
Sourcepub fn new<D>(display: &DisplayHandle) -> Selfwhere
D: GlobalDispatch<WlCompositor, GlobalData> + GlobalDispatch<WlSubcompositor, GlobalData> + 'static,
pub fn new<D>(display: &DisplayHandle) -> Selfwhere
D: GlobalDispatch<WlCompositor, GlobalData> + GlobalDispatch<WlSubcompositor, GlobalData> + 'static,
Create new wl_compositor version 5 and wl_subcompositor globals.
It returns the two global handles, in case you wish to remove these globals from the event loop in the future.
Sourcepub fn new_v6<D>(display: &DisplayHandle) -> Selfwhere
D: GlobalDispatch<WlCompositor, GlobalData> + GlobalDispatch<WlSubcompositor, GlobalData> + 'static,
pub fn new_v6<D>(display: &DisplayHandle) -> Selfwhere
D: GlobalDispatch<WlCompositor, GlobalData> + GlobalDispatch<WlSubcompositor, GlobalData> + 'static,
The same as new, but binds at least version 6 of wl_compositor.
This means that for clients to scale and apply transformation with
non-default values send_surface_state must be used.
Sourcepub fn compositor_global(&self) -> GlobalId
pub fn compositor_global(&self) -> GlobalId
Get id of compositor global
Sourcepub fn subcompositor_global(&self) -> GlobalId
pub fn subcompositor_global(&self) -> GlobalId
Get id of subcompositor global